import { TemplateRef } from '@angular/core';
import { Observable } from 'rxjs';
import { DkFilter, DkTextFilter, DkTextCaseFilter, DkNumericFilter, DkBinaryFilter, DkDateFilter } from '../filtering/dk-filter.model';
import { DkGridPanel } from '../panels/dk-grid-panels';
import { EditionFieldSettings } from '../editing/dk-edition.model';
import { CustomTextCaseFilterCondition } from '../filtering/dk-text-filter.conditions';
import { CustomMultipleTextFilterCondition } from '../filtering/dk-multiple-text-filter.conditions';
import { CustomNumericFilterCondition } from '../filtering/dk-numeric-filter.conditions';
import { CustomMultipleNumericFilterCondition } from '../filtering/dk-multiple-numeric-filter.condition';
import { CustomDateFilterCondition } from '../filtering/dk-date-filter.conditions';
import { CustomBinaryFilterCondition } from '../filtering/dk-binary-filter.conditions';
import { CustomFilterConditionInstance } from '../filtering/dk-filter-factory.service';
export declare type DisplayStatus = 'closed' | 'open';
export declare type DkColumnDataType = 'Text' | 'Numeric' | 'Date' | 'Binary';
export declare type ColumnAlignment = 'left' | 'center' | 'right' | 'start' | 'end';
export declare type GetterFn<T extends object, R extends string | number | Date | boolean | null | undefined> = (entry: T) => R;
export declare type SetterFn<T extends object, R extends string | number | Date | boolean | null | undefined> = (entry: T, value: R) => void;
export declare type ColumnMovement = 'swap-columns' | 'join-column-groups' | 'column-after' | 'column-before' | 'columns-to-panel';
export interface DkColumnMoveEvent {
    type: ColumnMovement;
    movedColumns: DkColumnDef[];
    beforeColumn?: DkColumnDef;
    afterColumn?: DkColumnDef;
    destinationPanel?: DkGridPanel;
}
export declare abstract class DkColumnDef {
    slotId: string | null;
    belongToGroup: string | null;
    columnId: string | null;
    get fieldName(): string;
    protected _fieldName: string;
    get headerText(): string;
    protected _headerText: string;
    order: number;
    headerTooltip: string;
    resizable: boolean;
    draggable: boolean;
    locked: boolean;
    visible: boolean;
    displayMenu: boolean;
    panel: DkGridPanel;
    displayOn: DisplayStatus;
    constructor(fieldName: string, headerText: string);
    assign(column: DkColumnDef): this;
}
export declare class DkGroupColumnDef extends DkColumnDef {
    children: DkColumnDef[];
    displayStatus: DisplayStatus;
    constructor(fieldName: string, headerText: string);
    assign(column: DkGroupColumnDef): this;
}
export declare abstract class DkDataColumnDef<T extends object, R extends string | number | Date | boolean | null | undefined> extends DkColumnDef {
    get dataType(): DkColumnDataType;
    protected _dataType: DkColumnDataType;
    width: number;
    minWidth: number;
    maxWidth: number;
    contentAlign: ColumnAlignment;
    sortable: boolean;
    filterable: boolean;
    editable: boolean;
    groupable: boolean;
    abstract get filter(): DkFilter[];
    abstract set filter(value: DkFilter[]);
    abstract get customFilterConditions(): CustomFilterConditionInstance<T>;
    abstract set customFilterConditions(value: CustomFilterConditionInstance<T>);
    editionSettings: EditionFieldSettings;
    editionTemplate: Observable<TemplateRef<any> | null | undefined> | TemplateRef<any> | null | undefined;
    displayTemplate: Observable<TemplateRef<any> | null | undefined> | TemplateRef<any> | null | undefined;
    constructor(fieldName: string, headerText: string, dataType: DkColumnDataType);
    assign(column: DkDataColumnDef<T, R>): this;
    static getDataColumnDefInstance<T extends object>(fieldName: string, headerText: string, dataType: DkColumnDataType): DkDataColumnDef<T, string | number | Date | boolean | null | undefined>;
    abstract getValue: GetterFn<T, R>;
    abstract setValue: SetterFn<T, R>;
}
export declare class DkTextColumnDef<T extends object> extends DkDataColumnDef<T, string | null | undefined> {
    private _filter;
    private _customFilterConditions;
    constructor(fieldName: string, headerText: string);
    get filter(): DkTextFilter[] | DkTextCaseFilter[];
    set filter(value: DkTextFilter[] | DkTextCaseFilter[]);
    get customFilterConditions(): CustomTextCaseFilterCondition<T> | CustomMultipleTextFilterCondition<T>;
    set customFilterConditions(value: CustomTextCaseFilterCondition<T> | CustomMultipleTextFilterCondition<T>);
    getValue: GetterFn<T, string | null | undefined>;
    setValue: SetterFn<T, string | null | undefined>;
}
export declare class DkNumericColumnDef<T extends object> extends DkDataColumnDef<T, number | null | undefined> {
    private _filter;
    private _customFilterConditions;
    constructor(fieldName: string, headerText: string);
    get filter(): DkNumericFilter[];
    set filter(value: DkNumericFilter[]);
    get customFilterConditions(): CustomNumericFilterCondition<T> | CustomMultipleNumericFilterCondition<T>;
    set customFilterConditions(value: CustomNumericFilterCondition<T> | CustomMultipleNumericFilterCondition<T>);
    getValue: GetterFn<T, number | null | undefined>;
    setValue: SetterFn<T, number | null | undefined>;
}
export declare class DkDateColumnDef<T extends object> extends DkDataColumnDef<T, string | number | Date | null | undefined> {
    private _filter;
    private _customFilterConditions;
    constructor(fieldName: string, headerText: string);
    get filter(): DkDateFilter[];
    set filter(value: DkDateFilter[]);
    get customFilterConditions(): CustomDateFilterCondition<T>;
    set customFilterConditions(value: CustomDateFilterCondition<T>);
    getValue: GetterFn<T, string | number | Date | null | undefined>;
    setValue: SetterFn<T, string | number | Date | null | undefined>;
}
export declare class DkBinaryColumnDef<T extends object> extends DkDataColumnDef<T, string | number | boolean | null | undefined> {
    private _filter;
    private _customFilterConditions;
    constructor(fieldName: string, headerText: string);
    get filter(): DkBinaryFilter[];
    set filter(value: DkBinaryFilter[]);
    get customFilterConditions(): CustomBinaryFilterCondition<T>;
    set customFilterConditions(value: CustomBinaryFilterCondition<T>);
    getValue: GetterFn<T, string | number | boolean | null | undefined>;
    setValue: SetterFn<T, string | number | boolean | null | undefined>;
}
export interface DkNodeColumnDef {
    column: DkColumnDef;
    parent?: DkNodeColumnDef;
    children?: DkNodeColumnDef[];
}
export declare function isDkGroupColumnDef(column: DkColumnDef): column is DkGroupColumnDef;
export declare function isDkDataColumnDef<T extends object, R extends string | number | Date | boolean | null | undefined>(column: DkColumnDef): column is DkDataColumnDef<T, R>;
