import { TemplateRef } from '@angular/core';
import { BehaviorSubject, Observable } from 'rxjs';
import { DkSlotPlacement } from '../common/dk-slot-placement';
import { DkColumn } from './dk-column';
import { DropConnectedElements } from '../common/dk-draggable-containers';
import { DisplayStatus } from './dk-column-def';
import { EditionFieldSettings } from '../editing/dk-edition.model';
export declare const ROOT_GROUP_ID: string;
export interface ColumnPayload {
    isForHeaderRow: boolean;
}
export interface ColumnOverPayload extends ColumnPayload {
    isOver: boolean;
}
export interface ColumnResizingPayload extends ColumnPayload {
    isResizing: boolean;
}
export declare abstract class DkMeshSlot {
    slotPosition: DkSlotPlacement;
    dikeColumn: DkColumn;
    /**
     * Permanent slot identifier.
     *
     * At insertion time,  we are going to generate a UUID that will
     * not change during execution. The generated Id will be stored
     * in slotId variable.
     *
     * We must create this UUID and store it at the level of the slot
     * because the dikeColumn's columnId must change when we drag columns
     * due to the MatSort header needs an Id. Remember that letting the
     * same Id when we move columns to other panel causes a collision.
     */
    slotId: string;
    belongToGroup: string;
    slotHeight: number;
    connectedSiblingIds: DropConnectedElements;
    /**
     * initialDisplayOn property will store the original value
     * when the slot is created. This value will not change during
     * the execution:
     */
    initialDisplayOn: DisplayStatus;
    /**
     * currentdisplayOn will store the new value after validating
     * all the level-list where the slot lives. This value will
     * change during all execution:
     */
    currentDisplayOn: DisplayStatus;
    protected columnOverSubject: BehaviorSubject<ColumnOverPayload>;
    constructor(dikeColumn: DkColumn);
    get onColumnOverChanged$(): Observable<ColumnOverPayload>;
    isColumnOver(value: ColumnOverPayload): void;
    protected changeColumnOver(value: ColumnOverPayload): void;
}
export declare class DkGutterMeshSlot extends DkMeshSlot {
    private columnResizingSubject;
    constructor(dikeColumn: DkColumn);
    get onColumnResizingChanged$(): Observable<ColumnResizingPayload>;
    isColumnResizing(value: ColumnResizingPayload): void;
    private changeColumnResizing;
}
export declare class DkColumnMeshSlot extends DkMeshSlot {
    dikeGutterSlot: DkGutterMeshSlot;
    complementDikeGutterSlot: DkGutterMeshSlot;
    horizontalGutter: DkSlotPlacement;
    /**
     * If there is only one node in a list then the node will be
     * the first and the last node in the list.
     */
    isFirst: boolean;
    isLast: boolean;
    displayStatus: DisplayStatus;
    /**
     * This value will be changed during all the execution after validating
     * if the group could be open and closed, depending on its children
     * displayOn property:
     */
    canChangeDisplayStatus: boolean;
    editionSettings: EditionFieldSettings;
    editionTemplate: TemplateRef<any> | null | undefined;
    displayTemplate: TemplateRef<any> | null | undefined;
    constructor(dikeColumn: DkColumn, dikeGutterColumn?: DkColumn);
}
