import { DoubleLinkedList, INode } from '../common/double-linked-list';
import { DkSlotPlacement } from '../common/dk-slot-placement';
import { DkColumnMeshSlot, DkMeshSlot, DkGutterMeshSlot } from './dk-column-mesh-slot';
import { DropConnectedElements } from '../common/dk-draggable-containers';
import { DkColumnDef, DisplayStatus } from './dk-column-def';
import { DkGridFactoryColumns } from './dk-grid-factory-columns.service';
export declare abstract class DkColumnMesh extends DoubleLinkedList<DkColumnMeshSlot> {
    protected listSiblingDropIds: DropConnectedElements;
    protected belongToGroupId: string;
    constructor(belongToGroupId: string);
    insert(value: DkColumnMeshSlot, children: DoubleLinkedList<DkColumnMeshSlot>): void;
    /**
     * Remove the given column slot from the current list instance.
     *
     * If the current list turns out empty after deleting the given column slot,
     * the parent column slot is deleted as well. If the parent column slot turns out
     * empty then the parent of the parent slot is deleted as well and so forth.
     *
     * @param {DkGridFactoryColumns} gridFactoryColumns The factory which helps creating each DkColumnDef instance.
     * @param {DkColumnMeshSlot} columnSlot The column slot which represents the column to be removed.
     * @returns {DkColumnDef} Returns the DkColumnDef instance which represents the deleted column.
     */
    removeColumnMeshSlot<T extends object>(gridFactoryColumns: DkGridFactoryColumns<T>, columnSlot: DkColumnMeshSlot): DkColumnDef;
    getNodesInOrder(displayStatus: DisplayStatus): DkColumnMeshSlot[];
    getLeavesArray(displayStatus: DisplayStatus): DkColumnMeshSlot[];
    getDikeColumnMeshSlot(columnId: string): DkColumnMeshSlot;
    getDikeMeshSlot(columnId: string): DkMeshSlot;
    getDikeColumnMeshSlotByUniqueId(slotId: string, isTreeSearch?: boolean): DkColumnMeshSlot;
    getDikeMeshSlotByUniqueId(slotId: string): DkMeshSlot;
    getChildrenLeavesFromColumnMeshSlot(columnId: string): DkColumnMeshSlot[];
    getVisibleColumnMeshSlots(): DkColumnMeshSlot[];
    getListDropppableIdsByBelongToGroupMeshSlot(belongToGroupId: string): DropConnectedElements;
    getDikeColumnMeshListInstance(belongToGroupId: string): DkColumnMesh;
    /**
     * Instance list method.
     *
     * Firstly, the INode<DkColumnMeshSlot>, where the column slot is stored,
     * is retrieved. Then the column slot is cloned creating a DkColumnDef
     * instance.
     *
     * Lastly, all column slots descendants are cloned.
     *
     * @param {DkGridFactoryColumns} gridFactoryColumns The factory which helps creating each DkColumnDef instance.
     * @param {string} columnId The column id which represents the column to be cloned.
     * @returns {DkColumnDef} The cloned column stored in a DkColumnDef instance.
     */
    getClonedDikeColumnDefToDepth<T extends object>(gridFactoryColumns: DkGridFactoryColumns<T>, columnId: string): DkColumnDef;
    /**
     * Instance list method.
     *
     * Firstly, the INode<DkColumnMeshSlot>, where the column slot is stored,
     * is retrieved. Then the column slot and all its descendants are cloned.
     *
     * Lastly, the line of ascent is retrieved.
     *
     * @param {DkGridFactoryColumns} gridFactoryColumns The factory which helps creating each DkColumnDef.
     * @param {string} columnId The column id which represents the column to be cloned.
     * @returns {DkColumnDef} The cloned line of ascent stored in a DkColumnDef instance.
     */
    getClonedDikeColumnDefBranch<T extends object>(gridFactoryColumns: DkGridFactoryColumns<T>, columnId: string): DkColumnDef;
    setColumnMeshSlotVisible(columnSlot: DkColumnMeshSlot, isVisible: boolean): boolean;
    isColumnMeshVisible(): boolean;
    doesNodeSlotExist(slotId: string, isTreeSearch?: boolean): boolean;
    /**
     *
     * Source and destination nodes will be interchage between them.
     *
     * Source and destination slots must live in the same instance list.
     *
     * @param {DkColumnMeshSlot} sourceColumnSlot The source, data or group, column.
     * @param {DkColumnMeshSlot} destinationColumnSlot The destination, data or group, column.
     *
     * @returns {boolean} True if swapping operation was successfuly acomplished.
     */
    swapColumnSlotNodes(sourceColumnSlot: DkColumnMeshSlot, destinationColumnSlot: DkColumnMeshSlot): boolean;
    calculateListVisibleHeight(displayStatus: DisplayStatus): number;
    verifyColumnVisibility(): boolean;
    verifyGroupColumnDisplayStatus(): Record<DisplayStatus, number>;
    setColumnMeshSlotsOrder(index: number): void;
    changeColumnMeshSlotReference(oldRef: DkColumnMeshSlot, newRef: DkColumnMeshSlot): boolean;
    protected setListVisibility(isVisible: boolean): void;
    /**
     * Instance list method.
     *
     * This method must be called from a parent node,
     * if the parent has children slot nodes.
     *
     * @param {DkGridFactoryColumns} gridFactoryColumns The factory which helps creating each DkColumnDef.
     * @returns {DkColumnDef[]} The cloned children slots.
     */
    protected cloneChildrenDikeColumnMeshSlotNodes<T extends object>(gridFactoryColumns: DkGridFactoryColumns<T>): DkColumnDef[];
    /**
     * Instance list method.
     *
     * A column slot is stored in a new instance of type DkColumnDef when cloning.
     * Remember only a Group column or a Data column could be cloned. Otherwise, an
     * Error is thrown.
     *
     * @param {DkGridFactoryColumns} gridFactoryColumns The factory which helps creating each DkColumnDef.
     * @param {DkColumnMeshSlot} columnSlot The column slot to be cloned.
     * @returns {DkColumnDef} The cloned column slot.
     */
    protected createClonedDikeColumnDefFromColumnSlot<T extends object>(gridFactoryColumns: DkGridFactoryColumns<T>, columnSlot: DkColumnMeshSlot): DkColumnDef;
    protected getDikeColumnMeshSlotNode(columnId: string, isTreeSearch?: boolean): INode<DkColumnMeshSlot>;
    protected getChildrenIds(displayStatus: DisplayStatus): void;
    protected spreadSiblingColumnIds(displayStatus: DisplayStatus): void;
    protected calculateOuterColumnMeshSlotsPlacement(currentHeight: number, gridColumnStart: number, gridRowStart: number, outerSlots: DkColumnMeshSlot[]): number;
    protected calculateScrollbarGapMeshSlotPlacement(currentHeight: number, gridColumnStart: number, gridRowStart: number, scrollbarGapSlot: DkColumnMeshSlot): number;
    protected calculateOuterColumnSlotsContainerWidth(outerSlots: DkColumnMeshSlot[]): number;
    protected getOuterColumnSlotsTemplate(outerColumSlots: DkColumnMeshSlot[]): string;
    protected getFirstVisibleNode(displayStatus: DisplayStatus, descendant?: boolean): INode<DkColumnMeshSlot>;
    protected setFirstVisibleNodesInTree(displayStatus: DisplayStatus): void;
    protected getLastVisibleNode(displayStatus: DisplayStatus, descendant?: boolean): INode<DkColumnMeshSlot>;
    protected setLastVisibleNodesInTree(displayStatus: DisplayStatus): void;
    protected resetDikeColumnSlotGutters(): void;
    protected changeDisplayOnStatus(status: DisplayStatus): void;
    abstract getContentMeshTemplate(displayStatus: DisplayStatus, outerSlots: DkColumnMeshSlot[]): string;
    abstract getHeaderMeshTemplate(displayStatus: DisplayStatus, outerSlots: DkColumnMeshSlot[], scrollbarGapSlot: DkColumnMeshSlot): string;
    abstract setColumnMeshSlotPlacement(displayStatus: DisplayStatus, greatestHeight: number, outerSlots: DkColumnMeshSlot[], scrollbarGapSlot: DkColumnMeshSlot): DkSlotPlacement;
    protected abstract calculateColumnMeshSlotsPlacement(displayStatus: DisplayStatus, currentHeight: number, gridColumnStart: number, gridRowStart: number): number;
    abstract calculateContainerWidth(displayStatus: DisplayStatus, outerSlots: DkColumnMeshSlot[], scrollbarGapSlot: DkColumnMeshSlot): number;
    protected abstract calculateColumnSlotsMeshContainerWidth(displayStatus: DisplayStatus): number;
    abstract swapToGutterSlotNode(sourceColumnSlot: DkColumnMeshSlot, destinationGutterSlot: DkMeshSlot): boolean;
    protected abstract getColumnSlotsTemplate(displayStatus: DisplayStatus): string;
    protected abstract setComplementDikeGutterSlot(displayStatus: DisplayStatus): void;
    abstract isComplementGutter(gutter: DkGutterMeshSlot): boolean;
    abstract getEdgeGutters(displayStatus: DisplayStatus, isComplementGutter: boolean): DkGutterMeshSlot[];
}
