import { DkGridPanel } from '../panels/dk-grid-panels';
import { GetterFn, SetterFn, DkColumnDataType, ColumnAlignment } from './dk-column-def';
export declare type DkColumnType = 'Group-Column' | 'Data-Column' | 'Gutter-Column' | 'Row-Index-Column' | 'Scrollbar-Gap-Column';
export declare abstract class DkColumn {
    columnId: string;
    get fieldName(): string;
    protected _fieldName: string;
    get headerText(): string;
    protected _headerText: string;
    get dataType(): DkColumnDataType;
    protected _dataType: DkColumnDataType;
    order: number;
    width: number;
    minWidth: number;
    maxWidth: number;
    contentAlign: ColumnAlignment;
    headerTooltip: string;
    resizable: boolean;
    draggable: boolean;
    locked: boolean;
    visible: boolean;
    sortable: boolean;
    filterable: boolean;
    editable: boolean;
    groupable: boolean;
    displayMenu: boolean;
    columnType: DkColumnType;
    panel: DkGridPanel;
    constructor(fieldName: string, headerText: string);
    resizeWidth(value: number): boolean;
    assign(column: DkColumn): this;
    protected setWidth(value: number): boolean;
}
export declare class DkGutterColumn extends DkColumn {
    columnIdBelongTo: string;
    constructor(fieldName: string);
    assign(column: DkGutterColumn): this;
}
export declare class DkRowIndexColumn extends DkColumn {
    constructor(headerText: string);
}
export declare class DkScrollbarGapColumn extends DkColumn {
    constructor();
}
export declare class DkDataColumn<T extends object, R extends string | number | Date | boolean | null | undefined> extends DkColumn {
    getValue: GetterFn<T, R>;
    setValue: SetterFn<T, R>;
    constructor(fieldName: string, headerText: string, dataType: DkColumnDataType);
    assign(column: DkDataColumn<T, R>): this;
    private getContentAlignment;
}
export declare class DkGroupColumn extends DkColumn {
    constructor(groupName: string, headerText: string);
}
