import { AsyncValidatorFn, ValidatorFn } from '@angular/forms';
import { DkBinarySelectionModel, DkNumericSelectionModel, DkTextSelectionModel } from '../common/dk-selection-model';
import { SetterFn } from '../columns/dk-column-def';
import { CustomErrorMessage } from './dk-edition-message.errors';
import { DkGridColumnDef } from '../columns/dk-grid-column-def.service';
export declare type EditionToolbarPosition = 'top' | 'bottom';
export declare type EditionToolbarAlignment = 'left' | 'center' | 'right';
export declare type RowStatus = 'Read' | 'Modified' | 'Deleted' | 'Editing';
export interface RowEditionActions {
    edit: boolean;
    delete: boolean;
    save: boolean;
    cancel: boolean;
}
export interface FieldUpdate<T extends object, R extends string | number | Date | boolean | null | undefined> {
    updateValue: SetterFn<T, R>;
    value: R;
}
export interface RowFormField {
    slotId: string;
    fieldName: string;
    headerText: string;
    value: any;
    touched: boolean;
    dirty: boolean;
    validators?: ValidatorFn[];
    asyncValidators?: AsyncValidatorFn[];
    updateOn: 'change' | 'blur' | 'submit';
}
export interface CrossFieldValidationSettings<T extends object> {
    customValidator?: (columnDef: DkGridColumnDef<T>) => ValidatorFn;
    customAsyncValidator?: (columnDef: DkGridColumnDef<T>) => AsyncValidatorFn;
    updateOn?: 'change' | 'blur' | 'submit';
    errorMessages: CustomErrorMessage;
}
export interface EditionFieldSettings {
    required?: boolean;
    validators?: ValidatorFn[];
    asyncValidators?: AsyncValidatorFn[];
    updateOn?: 'change' | 'blur' | 'submit';
    options?: DkBinarySelectionModel[] | DkNumericSelectionModel[] | DkTextSelectionModel[];
    errorMessages?: CustomErrorMessage;
}
export interface DkGridEditionSettings<T extends object> {
    maxRowsInEdition?: number;
    rowEditionDblClick?: boolean;
    rowEditionEnterkey?: boolean;
    rowEditionEscKey?: boolean;
    splitDeleteOperation?: boolean;
    deleteOperationRowSubsetSize?: number;
    splitUndoOperation?: boolean;
    undoOperationRowSubsetSize?: number;
    crossFieldValidation?: CrossFieldValidationSettings<T>;
    waitForMultipleRowsDeletion?: boolean;
    waitForMultipleRowsUpdate?: boolean;
    waitForMultipleRowsCancelation?: boolean;
    waitForMultipleRowsRestoration?: boolean;
}
