import { DkFilter, DkTextFilter, DkNumericFilter, DkBinaryFilter, DkTextCaseFilter, DkDateFilter } from './dk-filter.model';
import { DkFilterable } from "./dk-filter.model";
import { DkFilterCondition } from './dk-filter-types';
import { DkDataColumnDef } from '../columns/dk-column-def';
export interface DkFilterableDispatcher<T extends object> extends DkFilterable<T> {
    orConditions: DkFilter[];
    andConditions: DkFilter[];
}
/**
 * This classes are responsible for filtering execution.
 * All the instances are created by DkFilterFactory class.
 */
export declare abstract class DkFilterDispatcherConditions<T extends object, R extends string | number | Date | boolean | null | undefined, V> {
    protected filterConditions: DkFilterCondition<T, R, V>;
    constructor();
    abstract orConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, R>): boolean;
    abstract andConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, R>): boolean;
}
export declare class DkTextCaseFilterDispatcherConditions<T extends object> extends DkFilterDispatcherConditions<T, string | null | undefined, DkTextCaseFilter> {
    constructor(textFilterConditions: DkFilterCondition<T, string, DkTextCaseFilter>);
    orConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, string | null | undefined>): boolean;
    andConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, string | null | undefined>): boolean;
}
export declare class DkNumericFilterDispatcherConditions<T extends object> extends DkFilterDispatcherConditions<T, number | null | undefined, DkNumericFilter> {
    constructor(numericFilterConditions: DkFilterCondition<T, number | null | undefined, DkNumericFilter>);
    orConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, number | null | undefined>): boolean;
    andConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, number | null | undefined>): boolean;
}
export declare class DkDateFilterDispatcherConditions<T extends object> extends DkFilterDispatcherConditions<T, string | number | Date | null | undefined, DkDateFilter> {
    constructor(dateFilterConditions: DkFilterCondition<T, string | number | Date | null | undefined, DkDateFilter>);
    orConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, string | number | Date | null | undefined>): boolean;
    andConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, string | number | Date | null | undefined>): boolean;
}
export declare class DkBinaryFilterDispatcherConditions<T extends object> extends DkFilterDispatcherConditions<T, string | number | boolean | null | undefined, DkBinaryFilter> {
    constructor(binaryFilterConditions: DkFilterCondition<T, string | number | boolean | null | undefined, DkBinaryFilter>);
    orConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, string | number | boolean | null | undefined>): boolean;
    andConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, string | number | boolean | null | undefined>): boolean;
}
export declare class DkMultipleNumericFilterDispatcherConditions<T extends object> extends DkFilterDispatcherConditions<T, number | null | undefined, DkNumericFilter> {
    constructor(multipleNumericFilterConditions: DkFilterCondition<T, number, DkNumericFilter>);
    orConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, number | null | undefined>): boolean;
    andConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, number | null | undefined>): boolean;
}
export declare class DkMultipleTextFilterDispatcherConditions<T extends object> extends DkFilterDispatcherConditions<T, string | null | undefined, DkTextFilter> {
    constructor(multipleTextFilterConditions: DkFilterCondition<T, string | null | undefined, DkTextFilter>);
    orConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, string | null | undefined>): boolean;
    andConditionsEval(entry: T, filterable: DkFilterableDispatcher<T>, dataColumnDef: DkDataColumnDef<T, string | null | undefined>): boolean;
}
