import { DkFilterable, DkFilter } from './dk-filter.model';
import { DkTextCaseFilterDispatcherConditions, DkNumericFilterDispatcherConditions, DkBinaryFilterDispatcherConditions, DkDateFilterDispatcherConditions, DkMultipleNumericFilterDispatcherConditions, DkMultipleTextFilterDispatcherConditions } from './dk-filter-dispatcher-types';
import { CustomTextCaseFilterCondition, CustomRowTextCaseFilterCondition } from './dk-text-filter.conditions';
import { CustomNumericFilterCondition, CustomRowNumericFilterCondition } from './dk-numeric-filter.conditions';
import { CustomDateFilterCondition, CustomRowDateFilterCondition } from './dk-date-filter.conditions';
import { DkBinaryFilterCondition, CustomBinaryFilterCondition } from './dk-binary-filter.conditions';
import { DkMultipleNumericFilterCondition, CustomMultipleNumericFilterCondition } from './dk-multiple-numeric-filter.condition';
import { DkMultipleTextFilterCondition, CustomMultipleTextFilterCondition } from './dk-multiple-text-filter.conditions';
import { DkConfig } from '../grid/dk-config';
import * as i0 from "@angular/core";
export interface DkGridCustomFilterConditions<T extends object> {
    customTextFilterConditions?: CustomTextCaseFilterCondition<T>;
    customNumericFilterConditions?: CustomNumericFilterCondition<T>;
    customDateFilterConditions?: CustomDateFilterCondition<T>;
    customBinaryFilterConditions?: CustomBinaryFilterCondition<T>;
    customRowTextFilterConditions?: CustomRowTextCaseFilterCondition<T>;
    customRowNumericFilterConditions?: CustomRowNumericFilterCondition<T>;
    customRowDateFilterConditions?: CustomRowDateFilterCondition<T>;
}
export declare type DkFilterDispatcherConditionsInstance<T extends object> = DkTextCaseFilterDispatcherConditions<T> | DkNumericFilterDispatcherConditions<T> | DkDateFilterDispatcherConditions<T> | DkBinaryFilterDispatcherConditions<T> | DkMultipleNumericFilterDispatcherConditions<T> | DkMultipleTextFilterDispatcherConditions<T>;
/**
 * The most important features are the Condition<T, R, V> array and options which live in
 * DkFilterCondition<T, R, V> and DkSelectionFilterCondition<M, T, R, V> respectively. Therefore,
 * we need the complete instance:
 */
export declare type CustomFilterConditionInstance<T extends object> = CustomTextCaseFilterCondition<T> | CustomRowTextCaseFilterCondition<T> | CustomNumericFilterCondition<T> | CustomRowNumericFilterCondition<T> | CustomDateFilterCondition<T> | CustomRowDateFilterCondition<T> | CustomBinaryFilterCondition<T> | CustomMultipleNumericFilterCondition<T> | CustomMultipleTextFilterCondition<T>;
export declare type DkSelectionFilterConditionInstance<T extends object> = DkBinaryFilterCondition<T> | CustomBinaryFilterCondition<T> | DkMultipleNumericFilterCondition<T> | CustomMultipleNumericFilterCondition<T> | DkMultipleTextFilterCondition<T> | CustomMultipleTextFilterCondition<T>;
export declare type CustomSelectionFilterConditionInstance<T extends object> = CustomBinaryFilterCondition<T> | CustomMultipleNumericFilterCondition<T> | CustomMultipleTextFilterCondition<T>;
export declare class DkFilterFactory<T extends object> {
    private dikeConfig;
    private customTextFilterConditions;
    private customNumericFilterConditions;
    private customDateFilterConditions;
    private customBinaryFilterConditions;
    private customRowTextFilterConditions;
    private customRowNumericFilterConditions;
    private customRowDateFilterConditions;
    private gridCustomFilterConditions;
    private dikeTextFilterConditions;
    private dikeNumericFilterConditions;
    private dikeDateFilterConditions;
    private dikeBinaryFilterConditions;
    constructor(dikeConfig: DkConfig, customTextFilterConditions: CustomTextCaseFilterCondition<T>, customNumericFilterConditions: CustomNumericFilterCondition<T>, customDateFilterConditions: CustomDateFilterCondition<T>, customBinaryFilterConditions: CustomBinaryFilterCondition<T>, customRowTextFilterConditions: CustomRowTextCaseFilterCondition<T>, customRowNumericFilterConditions: CustomRowNumericFilterCondition<T>, customRowDateFilterConditions: CustomRowDateFilterCondition<T>);
    setGridCustomConditions(gridCustomConditions: DkGridCustomFilterConditions<T>): void;
    isCustomSelectionFilterCondition(value: CustomFilterConditionInstance<T>): value is CustomSelectionFilterConditionInstance<T>;
    isCustomTextFilterCondition(value: CustomFilterConditionInstance<T>): value is CustomRowTextCaseFilterCondition<T> | CustomTextCaseFilterCondition<T> | CustomMultipleTextFilterCondition<T>;
    isCustomNumericFilterCondition(value: CustomFilterConditionInstance<T>): value is CustomRowNumericFilterCondition<T> | CustomNumericFilterCondition<T> | CustomMultipleNumericFilterCondition<T>;
    isCustomDateFilterCondition(value: CustomFilterConditionInstance<T>): value is CustomRowDateFilterCondition<T> | CustomDateFilterCondition<T>;
    isCustomBinaryFilterCondition(value: CustomFilterConditionInstance<T>): value is CustomBinaryFilterCondition<T>;
    isCustomConditionInstanceValid(filterable: DkFilterable<T>): boolean;
    getFilterFromOptions(selectionInstance: DkSelectionFilterConditionInstance<T>): DkFilter[];
    private getBinaryFilterFromOptions;
    private getMultipleNumericFilterFromOptions;
    private getMultipleTextFilterFromOptions;
    getFilterConditionInstance(filterable: DkFilterable<T>): CustomFilterConditionInstance<T>;
    private getRowFilterCondition;
    private createRowTextFilterCondition;
    private createRowNumericFilterCondition;
    private createRowDateFilterCondition;
    private getContextFilterCondition;
    private createTextFilterCondition;
    private createNumericFilterCondition;
    private createDateFilterCondition;
    private createBinaryFilterCondition;
    getFilterDispatcherConditionInstance(filterable: DkFilterable<T>): DkFilterDispatcherConditionsInstance<T>;
    isRowFilter(filterable: DkFilterable<T>): boolean;
    private createTextFilterDispatcher;
    private createNumericFilterDispatcher;
    private createDateFilterDispatcher;
    private createBinaryFilterDispatcher;
    private isNullOrUndefined;
    static ɵfac: i0.ɵɵFactoryDeclaration<DkFilterFactory<any>, [null, { optional: true; }, { optional: true; }, { optional: true; }, { optional: true; }, { optional: true; }, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DkFilterFactory<any>>;
}
