import { DkDataColumnDef } from '../columns/dk-column-def';
export declare enum ConditionType {
    EQUALS = "equals",
    NOT_EQUALS = "notEquals",
    CONTAINS = "contains",
    NOT_CONTAINS = "notContains",
    STARTS_WITH = "startsWith",
    ENDS_WITH = "endsWith",
    LESS_THAN = "lessThan",
    LESS_THAN_OR_EQUAL = "lessThanOrEqual",
    GREATER_THAN = "greaterThan",
    GREATER_THAN_OR_EQUAL = "greaterThanOrEqual",
    RANGE = "range",
    EMPTY = "empty",
    NOT_EMPTY = "notEmpty"
}
export declare type LogicalOperator = 'and' | 'or';
export interface Condition<T extends object, R extends string | number | Date | boolean | null | undefined, V> {
    text: string;
    value: string;
    eval: (entry: T, dataColumnDef?: DkDataColumnDef<T, R>, values?: V) => boolean;
}
interface FilterCondition<T extends object, R extends string | number | Date | boolean | null | undefined, V> {
    [index: string]: Condition<T, R, V>;
}
export declare abstract class DkFilterCondition<T extends object, R extends string | number | Date | boolean | null | undefined, V> {
    protected indexConditions: FilterCondition<T, R, V>;
    constructor();
    assign(filterConditions: DkFilterCondition<T, R, V>): this;
    get conditions(): Condition<T, R, V>[];
    addCondition(condition: Condition<T, R, V>): this;
    removeCondition(name: string): Condition<T, R, V>;
    getCondition(name: string): Condition<T, R, V>;
}
export declare abstract class DkSelectionFilterCondition<M, T extends object, R extends string | number | Date | boolean | null | undefined, V> extends DkFilterCondition<T, R, V> {
    protected dikeFilterOptions: M[];
    constructor();
    abstract set options(options: M[]);
    abstract get options(): M[];
    assign(value: DkSelectionFilterCondition<M, T, R, V>): this;
    addCondition(condition: Condition<T, R, V>): this;
    protected isValidCondition(name: string): boolean;
}
export declare abstract class DkBinarySelectionFilterCondition<M, T extends object, V> extends DkSelectionFilterCondition<M, T, string | number | boolean | null | undefined, V> {
    private MAX_OPTIONS;
    constructor();
    set options(options: M[]);
    get options(): M[];
    assign(value: DkBinarySelectionFilterCondition<M, T, V>): this;
}
export declare abstract class DkMultipleSelectionFilterCondition<M, T extends object, R extends string | number | boolean | Date | null | undefined, V> extends DkSelectionFilterCondition<M, T, R, V> {
    constructor();
    set options(options: M[]);
    get options(): M[];
    assign(value: DkSelectionFilterCondition<M, T, R, V>): this;
}
export {};
