import { AfterContentInit, QueryList, AfterViewInit, OnChanges, SimpleChanges, OnDestroy, OnInit, Renderer2, ChangeDetectorRef, ElementRef, TemplateRef, EventEmitter } from '@angular/core';
import { Overlay, NoopScrollStrategy } from '@angular/cdk/overlay';
import { CdkDragDrop, CdkDragEnter, CdkDragExit } from '@angular/cdk/drag-drop';
import { BooleanInput, NumberInput } from '@angular/cdk/coercion';
import { MatSnackBar } from '@angular/material/snack-bar';
import { MatPaginator, PageEvent } from '@angular/material/paginator';
import { Observable, Subject } from 'rxjs';
import { DkGridColumnComponent } from '../../columns/dk-grid-column/dk-grid-column.component';
import { DkGridDataSourceInput, DkDataSource } from '../../datasource/dk-datasource';
import { DkGridDataRowEntry, DkGridRowEntry } from '../../rows/dk-grid-row-entry';
import { DkFilterable } from '../../filtering/dk-filter.model';
import { DkGridBorder, BorderType } from '../dk-grid.model';
import { DraggableContainer } from '../../common/dk-draggable-containers';
import { DkColumnMeshSlot } from '../../columns/dk-column-mesh-slot';
import { DkGridEditionSettings, EditionToolbarAlignment, EditionToolbarPosition } from '../../editing/dk-edition.model';
import { DkConfig } from '../dk-config';
import { DkGridWaitingIndicator } from '../dk-grid-waiting-indicator';
import { DkGroupColumnStructure } from '../../columns/dk-group-column-structure';
import { DkColumnDef, DkDataColumnDef, DkGroupColumnDef, DkColumnMoveEvent } from '../../columns/dk-column-def';
import { DkGroupRowCollapseEvent } from '../../row-grouping/dk-row-grouping.model';
import { DkGridConfig } from '../dk-grid-config.service';
import { DkGridContentStructure } from '../../content/dk-grid-content-structure.service';
import { DkGridUI } from '../dk-grid-ui.service';
import { DkGridSorting, DkColumnSortEvent } from '../../sorting/dk-grid-sorting.service';
import { DkSortDispatcher } from '../../sorting/dk-sort-dispatcher.service';
import { DkGridPanelDispatcher } from '../../panels/dk-grid-panel-dispatcher.service';
import { DkGridColumnDef } from '../../columns/dk-grid-column-def.service';
import { DkGridFilter } from '../../filtering/dk-grid-filter.service';
import { DkContentPanelDispatcher } from '../../content/dk-content-panel-dispatcher.service';
import { DkGridFactoryColumns } from '../../columns/dk-grid-factory-columns.service';
import { DkGridStructure } from '../dk-grid-structure.service';
import { DkFilterFactory, DkGridCustomFilterConditions } from '../../filtering/dk-filter-factory.service';
import { DkGridFilterConfig } from '../../filtering/dk-grid-filter-config.service';
import { DkGridMessaging } from '../dk-grid-messaging.service';
import { DataSourceDecoratorCtxFn, DataSourceDecoratorFn, DkDataSourceDispatcher } from '../../datasource/dk-data-source-dispatcher.service';
import { DkGridFactoryDataSource } from '../../datasource/dk-grid-factory-data-source.service';
import { DkGridEdition } from '../../editing/dk-grid-edition.service';
import { DkGridEditionConfig } from '../../editing/dk-grid-edition-config.service';
import { DkGridSelection, SelectableFn } from '../../selection/dk-grid-selection.service';
import { DkGridSelectionConfig } from '../../selection/dk-grid-selection-config.service';
import { DkGridRowEditionDispatcher } from '../../editing/dk-grid-row-edition-dispatcher.service';
import { DkGeneralNotifier } from '../../common/dk-general-notifier.service';
import { DkGroupPanelDispatcher } from '../../row-grouping/dk-group-panel-dispatcher.service';
import { DkRowGroupingDispatcher } from '../../row-grouping/dk-row-grouping-dispatcher.service';
import { DkRowGroupingConfig } from '../../row-grouping/dk-row-grouping-config.service';
import { DkGridRowGrouping } from '../../row-grouping/dk-grid-row-grouping.service';
import { DkPaginationDispatcher } from '../../paging/dk-pagination-dispatcher.service';
import { DkGridPagination } from '../../paging/dk-grid-pagination.service';
import * as i0 from "@angular/core";
export declare function scrollFactory(overlay: Overlay): () => NoopScrollStrategy;
export declare class DkGridComponent<T extends object> implements OnInit, OnChanges, AfterContentInit, AfterViewInit, OnDestroy {
    private document;
    private dikeConfig;
    private cdr;
    private render2;
    private snackBar;
    private gridConfig;
    private gridMessaging;
    private gridFilter;
    private gridFilterConfig;
    private filterFactory;
    private gridColumnDef;
    private gridSorting;
    private sortDispatcher;
    private paginationDispatcher;
    private gridPagination;
    private gridStructure;
    private gridContentStructure;
    private gridUI;
    private gridFactoryColumns;
    private dataSourceDispatcher;
    private gridDataSourceFactory;
    private gridEdition;
    private gridEditionConfig;
    private rowEditionDispatcher;
    private gridSelection;
    private gridSelectionConfig;
    private generalNotifier;
    private gridPanelDispatcher;
    private contentPanelDispatcher;
    private groupPanelDispatcher;
    private rowGroupingConfig;
    private rowGroupingDispatcher;
    private gridRowGrouping;
    id: string;
    height: string;
    width: string;
    get displayRowId(): boolean;
    set displayRowId(value: any);
    private _displayRowId;
    static ngAcceptInputType_displayRowId: BooleanInput;
    get rowIdWidth(): number;
    set rowIdWidth(value: any);
    private _rowIdWidth;
    static ngAcceptInputType_rowIdWidth: NumberInput;
    get gridElevation(): boolean;
    set gridElevation(value: any);
    private _gridElevation;
    static ngAcceptInputType_gridElevation: BooleanInput;
    get gridElevationValue(): number;
    set gridElevationValue(value: any);
    private _gridElevationValue;
    static ngAcceptInputType_gridElevationValue: NumberInput;
    get verticalRowLines(): boolean;
    set verticalRowLines(value: any);
    private _verticalRowLines;
    static ngAcceptInputType_verticalRowLines: BooleanInput;
    get striped(): boolean;
    set striped(value: any);
    private _striped;
    static ngAcceptInputType_striped: BooleanInput;
    get headerRowHeight(): number;
    set headerRowHeight(value: any);
    private _headerRowHeight;
    static ngAcceptInputType_headerRowHeight: NumberInput;
    get contentRowHeight(): number;
    set contentRowHeight(value: any);
    private _contentRowHeight;
    static ngAcceptInputType_contentRowHeight: NumberInput;
    get allowRowGrouping(): boolean;
    set allowRowGrouping(value: any);
    private _allowRowGrouping;
    static ngAcceptInputType_allowRowGrouping: BooleanInput;
    get rowGroupingRowHeight(): number;
    set rowGroupingRowHeight(value: any);
    private _rowGroupingRowHeight;
    static ngAcceptInputType_rowGroupingRowHeight: NumberInput;
    get rowGroupingColumnHeight(): number;
    set rowGroupingColumnHeight(value: any);
    private _rowGroupingColumnHeight;
    static ngAcceptInputType_rowGroupingColumnHeight: NumberInput;
    get displayRowGroupingIndent(): boolean;
    set displayRowGroupingIndent(value: any);
    private _displayRowGroupingIndent;
    static ngAcceptInputType_displayRowGroupingIndent: BooleanInput;
    get rowGroupingIndentWidth(): number;
    set rowGroupingIndentWidth(value: any);
    private _rowGroupingIndentWidth;
    static ngAcceptInputType_rowGroupingIndentWidth: NumberInput;
    readonly groupPanelColumnsChange: EventEmitter<DkColumnDef[]>;
    readonly collapseGroupRowChange: EventEmitter<DkGroupRowCollapseEvent<T>>;
    get allowPagination(): boolean;
    set allowPagination(value: any);
    private _allowPagination;
    static ngAcceptInputType_allowPagination: BooleanInput;
    get pageSize(): number;
    set pageSize(value: any);
    private _pageSize;
    static ngAcceptInputType_pageSize: NumberInput;
    get paginationRowHeight(): number;
    set paginationRowHeight(value: any);
    private _paginationRowHeight;
    static ngAcceptInputType_paginationRowHeight: NumberInput;
    readonly pageChange: EventEmitter<PageEvent>;
    readonly paginatorChange: EventEmitter<MatPaginator>;
    get onDemandFilter(): boolean;
    set onDemandFilter(value: any);
    private _onDemandFilter;
    static ngAcceptInputType_onDemandFilter: BooleanInput;
    get allowRowFiltering(): boolean;
    set allowRowFiltering(value: any);
    private _allowRowFiltering;
    static ngAcceptInputType_allowRowFiltering: BooleanInput;
    get filterRowHeight(): number;
    set filterRowHeight(value: any);
    private _filterRowHeight;
    static ngAcceptInputType_filterRowHeight: NumberInput;
    gridCustomFilterConditions: DkGridCustomFilterConditions<T>;
    readonly registerFilterableChange: EventEmitter<DkFilterable<T>>;
    readonly deregisterFilterableChange: EventEmitter<DkFilterable<T>>;
    readonly filterChange: EventEmitter<DkFilterable<T>>;
    readonly editionFilterChange: EventEmitter<DkFilterable<T>>;
    readonly clearFilterChange: EventEmitter<void>;
    readonly clearEditionFilterChange: EventEmitter<void>;
    get allowEdition(): boolean;
    set allowEdition(value: any);
    private _allowEdition;
    static ngAcceptInputType_allowEdition: BooleanInput;
    get editionMode(): boolean;
    set editionMode(value: any);
    private _editionMode;
    static ngAcceptInputType_editionMode: BooleanInput;
    get editionToolbar(): boolean;
    set editionToolbar(value: any);
    private _editionToolbar;
    static ngAcceptInputType_editionToolbar: BooleanInput;
    editionToolbarPosition: EditionToolbarPosition;
    editionToolbarAlignment: EditionToolbarAlignment;
    get editionToolbarRowHeight(): number;
    set editionToolbarRowHeight(value: any);
    private _editionToolbarRowHeight;
    static ngAcceptInputType_editionToolbarRowHeight: NumberInput;
    get editionToolbarItemHeight(): number;
    set editionToolbarItemHeight(value: any);
    private _editionToolbarItemHeight;
    static ngAcceptInputType_editionToolbarItemHeight: NumberInput;
    gridEditionSettings: DkGridEditionSettings<T>;
    readonly editionRowChange: EventEmitter<DkGridDataRowEntry<T>>;
    readonly updateRowChange: EventEmitter<DkGridDataRowEntry<T> | DkGridDataRowEntry<T>[]>;
    readonly cancelRowEditionChange: EventEmitter<DkGridDataRowEntry<T> | DkGridDataRowEntry<T>[]>;
    readonly removeRowChange: EventEmitter<DkGridDataRowEntry<T> | DkGridDataRowEntry<T>[]>;
    readonly restoreRowChange: EventEmitter<DkGridDataRowEntry<T> | DkGridDataRowEntry<T>[]>;
    readonly editionFilterStateChange: EventEmitter<boolean>;
    get allowSelection(): boolean;
    set allowSelection(value: any);
    private _allowSelection;
    static ngAcceptInputType_allowSelection: BooleanInput;
    selectableRows: SelectableFn<T>;
    readonly selectionChange: EventEmitter<DkGridDataRowEntry<T>[]>;
    readonly selectedRowChange: EventEmitter<DkGridDataRowEntry<T>>;
    readonly deselectedRowChange: EventEmitter<DkGridDataRowEntry<T>>;
    datasource: DkGridDataSourceInput<T>;
    decoratorFn: DataSourceDecoratorFn<T>;
    readonly dataDeliveryIdChange: EventEmitter<string>;
    get allowColumnContextMenu(): boolean;
    set allowColumnContextMenu(value: any);
    private _allowColumnContextMenu;
    static ngAcceptInputType_allowColumnContextMenu: BooleanInput;
    get allowColumnDragging(): boolean;
    set allowColumnDragging(value: any);
    private _allowColumnDragging;
    static ngAcceptInputType_allowColumnDragging: BooleanInput;
    readonly gridColumnDefInstance: EventEmitter<DkGridColumnDef<T>>;
    dikeGridColumns: QueryList<DkGridColumnComponent<T, string | number | Date | boolean | null | undefined>>;
    get allowSorting(): boolean;
    set allowSorting(value: any);
    private _allowSorting;
    static ngAcceptInputType_allowSorting: BooleanInput;
    private _gridSort;
    readonly sortChange: EventEmitter<DkColumnSortEvent<T>>;
    readonly columnSizeChange: EventEmitter<DkDataColumnDef<T, string | number | Date | boolean | null | undefined>>;
    readonly columnGroupStatusChange: EventEmitter<DkGroupColumnDef>;
    readonly columnLockedChange: EventEmitter<DkColumnDef>;
    readonly columnUnLockedChange: EventEmitter<DkColumnDef>;
    readonly columnVisibleChange: EventEmitter<DkColumnDef>;
    readonly columnMove: EventEmitter<DkColumnMoveEvent>;
    readonly columnsChange: EventEmitter<DkColumnDef[]>;
    readonly contentPanelsColumnsChange: EventEmitter<DkColumnDef[]>;
    readonly columnsRemovedChange: EventEmitter<DkColumnDef[]>;
    divMainContainerRef: ElementRef;
    dikeTextBox: TemplateRef<any>;
    dikeMultiTextBox: TemplateRef<any>;
    dikeTextOptionsBox: TemplateRef<any>;
    dikeNumericBox: TemplateRef<any>;
    dikeNumericOptionsBox: TemplateRef<any>;
    dikeDateBox: TemplateRef<any>;
    dikeBinaryBox: TemplateRef<any>;
    dikeBinaryOptionsBox: TemplateRef<any>;
    dikeTextDisplay: TemplateRef<any>;
    dikeNumericDisplay: TemplateRef<any>;
    dikeDateDisplay: TemplateRef<any>;
    dikeBinaryDisplay: TemplateRef<any>;
    readonly filter: DkGridFilter<T>;
    readonly columnDef: DkGridColumnDef<T>;
    readonly edition: DkGridEdition<T>;
    readonly selection: DkGridSelection<T>;
    readonly sorting: DkGridSorting<T>;
    readonly pagination: DkGridPagination;
    readonly rowGrouping: DkGridRowGrouping<T>;
    readonly dataSourceFactory: DkGridFactoryDataSource<T>;
    readonly waitingIndicator: DkGridWaitingIndicator;
    get initialized(): boolean;
    isDragging$: Observable<boolean>;
    bordersGap: boolean;
    borderTop$: Observable<DkGridBorder>;
    borderRight$: Observable<DkGridBorder>;
    borderBottom$: Observable<DkGridBorder>;
    borderLeft$: Observable<DkGridBorder>;
    totalGridHeightPx: string;
    borderWidthPx: string;
    dropBorderContainer: DraggableContainer;
    dropBorderContainerWidthPx: string;
    editionToolbarVisibility$: Observable<boolean>;
    editionToolbarPosition$: Observable<EditionToolbarPosition>;
    mainWrapperId: string;
    gridSizeNotifier: Subject<void>;
    gridElevationClass: string;
    isWaitIndicatorActive: boolean;
    waitIndicatorMessage: string;
    customScrollbars: boolean;
    matSelectPanelClass: string;
    groupColumnStructure: DkGroupColumnStructure<T>;
    contentDataSource$: Observable<DkDataSource<DkGridRowEntry>>;
    /***********************************************/
    disableSortPagination$: Observable<boolean>;
    /***********************************************/
    private changeTotalGridHeightSubscription;
    private changeColumnDraggingSubscription;
    private changeGridElevationSubscription;
    private changeWaitIndicatorSubscription;
    private gridMessagingSubscription;
    constructor(document: Document, dikeConfig: DkConfig, cdr: ChangeDetectorRef, render2: Renderer2, snackBar: MatSnackBar, gridConfig: DkGridConfig, gridMessaging: DkGridMessaging, gridFilter: DkGridFilter<T>, gridFilterConfig: DkGridFilterConfig<T>, filterFactory: DkFilterFactory<T>, gridColumnDef: DkGridColumnDef<T>, gridSorting: DkGridSorting<T>, sortDispatcher: DkSortDispatcher<T>, paginationDispatcher: DkPaginationDispatcher, gridPagination: DkGridPagination, gridStructure: DkGridStructure<T>, gridContentStructure: DkGridContentStructure<T>, gridUI: DkGridUI, gridFactoryColumns: DkGridFactoryColumns<T>, dataSourceDispatcher: DkDataSourceDispatcher<T>, gridDataSourceFactory: DkGridFactoryDataSource<T>, gridEdition: DkGridEdition<T>, gridEditionConfig: DkGridEditionConfig<T>, rowEditionDispatcher: DkGridRowEditionDispatcher<T>, gridSelection: DkGridSelection<T>, gridSelectionConfig: DkGridSelectionConfig<T>, generalNotifier: DkGeneralNotifier, gridPanelDispatcher: DkGridPanelDispatcher<T>, contentPanelDispatcher: DkContentPanelDispatcher<T>, groupPanelDispatcher: DkGroupPanelDispatcher<T>, rowGroupingConfig: DkRowGroupingConfig, rowGroupingDispatcher: DkRowGroupingDispatcher<T>, gridRowGrouping: DkGridRowGrouping<T>);
    ngOnChanges(changes: SimpleChanges): void;
    ngOnInit(): void;
    ngAfterContentInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    onDropListEntered(entered: CdkDragEnter<string>): void;
    onDropListExited(exited: CdkDragExit<string>): void;
    onDrop(dropped: CdkDragDrop<BorderType, DkColumnMeshSlot>): void;
    getDecoratorCtxFn(dataSourceDecoratorFn: DataSourceDecoratorFn<T>): DataSourceDecoratorCtxFn<T>;
    releaseEdition(): void;
    releaseSelection(): void;
    private changeGridSizeNotifier;
    private setChangeTotalGridHeightSubscription;
    private setChangeGridElevationSubscription;
    private setChangeColumnDraggingSubscription;
    private setChangeWaitIndicatorSubscription;
    static ɵfac: i0.ɵɵFactoryDeclaration<DkGridComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DkGridComponent<any>, "dk-grid", ["dkgGrid"], { "id": "id"; "height": "height"; "width": "width"; "displayRowId": "displayRowId"; "rowIdWidth": "rowIdWidth"; "gridElevation": "gridElevation"; "gridElevationValue": "gridElevationValue"; "verticalRowLines": "verticalRowLines"; "striped": "striped"; "headerRowHeight": "headerRowHeight"; "contentRowHeight": "contentRowHeight"; "allowRowGrouping": "allowRowGrouping"; "rowGroupingRowHeight": "rowGroupingRowHeight"; "rowGroupingColumnHeight": "rowGroupingColumnHeight"; "displayRowGroupingIndent": "displayRowGroupingIndent"; "rowGroupingIndentWidth": "rowGroupingIndentWidth"; "allowPagination": "allowPagination"; "pageSize": "pageSize"; "paginationRowHeight": "paginationRowHeight"; "onDemandFilter": "onDemandFilter"; "allowRowFiltering": "allowRowFiltering"; "filterRowHeight": "filterRowHeight"; "gridCustomFilterConditions": "gridCustomFilterConditions"; "allowEdition": "allowEdition"; "editionMode": "editionMode"; "editionToolbar": "editionToolbar"; "editionToolbarPosition": "editionToolbarPosition"; "editionToolbarAlignment": "editionToolbarAlignment"; "editionToolbarRowHeight": "editionToolbarRowHeight"; "editionToolbarItemHeight": "editionToolbarItemHeight"; "gridEditionSettings": "gridEditionSettings"; "allowSelection": "allowSelection"; "selectableRows": "selectableRows"; "datasource": "datasource"; "decoratorFn": "decoratorFn"; "allowColumnContextMenu": "allowColumnContextMenu"; "allowColumnDragging": "allowColumnDragging"; "allowSorting": "allowSorting"; }, { "groupPanelColumnsChange": "groupPanelColumnsChange"; "collapseGroupRowChange": "collapseGroupRowChange"; "pageChange": "pageChange"; "paginatorChange": "paginatorChange"; "registerFilterableChange": "registerFilterableChange"; "deregisterFilterableChange": "deregisterFilterableChange"; "filterChange": "filterChange"; "editionFilterChange": "editionFilterChange"; "clearFilterChange": "clearFilterChange"; "clearEditionFilterChange": "clearEditionFilterChange"; "editionRowChange": "editionRowChange"; "updateRowChange": "updateRowChange"; "cancelRowEditionChange": "cancelRowEditionChange"; "removeRowChange": "removeRowChange"; "restoreRowChange": "restoreRowChange"; "editionFilterStateChange": "editionFilterStateChange"; "selectionChange": "selectionChange"; "selectedRowChange": "selectedRowChange"; "deselectedRowChange": "deselectedRowChange"; "dataDeliveryIdChange": "dataDeliveryIdChange"; "gridColumnDefInstance": "gridColumnDefInstance"; "sortChange": "sortChange"; "columnSizeChange": "columnSizeChange"; "columnGroupStatusChange": "columnGroupStatusChange"; "columnLockedChange": "columnLockedChange"; "columnUnLockedChange": "columnUnLockedChange"; "columnVisibleChange": "columnVisibleChange"; "columnMove": "columnMove"; "columnsChange": "columnsChange"; "contentPanelsColumnsChange": "contentPanelsColumnsChange"; "columnsRemovedChange": "columnsRemovedChange"; }, ["dikeGridColumns"], never>;
}
