import { EventEmitter } from '@angular/core';
import { BehaviorSubject, Observable, Subscription } from 'rxjs';
import { DkColumnStructure } from '../columns/dk-column-structure';
import { DkColumnMeshSlot, DkMeshSlot } from '../columns/dk-column-mesh-slot';
import { ShareableDropElements } from '../common/dk-draggable-containers';
import { DkGridPanel } from './dk-grid-panels';
import { DkColumnDef } from '../columns/dk-column-def';
export declare abstract class DkPanelDispatcher<T extends object, P extends DkGridPanel> {
    private panelInstances;
    readonly columnsChangedEmitter: EventEmitter<DkColumnDef[]>;
    readonly columnsRemovedEmitter: EventEmitter<DkColumnDef[]>;
    protected columnSlotsSubject: BehaviorSubject<DkColumnMeshSlot[]>;
    protected dataColumnSlotsSubject: BehaviorSubject<DkColumnMeshSlot[]>;
    protected shareableDropElementsSubject: BehaviorSubject<Record<P, ShareableDropElements>>;
    protected panels: Partial<Record<P, DkColumnStructure<T, P>>>;
    protected changesListHeightSubscription: Subscription;
    protected changesColumnSlotsSubscription: Subscription;
    protected changesDataColumnSlotsSubscription: Subscription;
    protected changesShareableDropElementsSubscription: Subscription;
    protected emitColumnsChangingSubscription: Subscription;
    constructor(panelInstances: DkColumnStructure<T, P>[]);
    destroy(): void;
    get onColumnSlotsChanged$(): Observable<DkColumnMeshSlot[]>;
    get onDataColumnSlotsChanged$(): Observable<DkColumnMeshSlot[]>;
    get onShareDropElementsChanged$(): Observable<Record<P, ShareableDropElements>>;
    cloneColumnSlot(columnSlot: DkColumnMeshSlot, lineOfAscent?: boolean): DkColumnDef;
    removeColumnSlot(columns: DkColumnDef | DkColumnDef[]): void;
    getColumnSlots(): DkColumnMeshSlot[];
    getDataColumnSlots(): DkColumnMeshSlot[];
    getAllDataColumnSlots(): DkColumnMeshSlot[];
    doesDataColumnSlotExist(panel: P, slotId: string): DkColumnMeshSlot;
    protected getColumnSlot(columnId: string): DkColumnMeshSlot;
    protected getSlot(columnId: string): DkMeshSlot;
    protected getShareDropElementIds(panel: DkColumnStructure<T, P>, panelSlots: DkColumnMeshSlot[]): ShareableDropElements;
    protected cleanInternalUseField(columns: DkColumnDef[]): void;
    protected setEmitColumnsChangingSubscription(): void;
    abstract addColumns(columns: DkColumnDef | DkColumnDef[]): void;
    abstract movePanelColumnSlots(fromPanel: DkColumnStructure<T, P>, destinationPanel: DkColumnStructure<T, P>, onlyVisibleColumnSlots: boolean): DkColumnDef[];
    abstract moveColumnSlotIntoPanel(columnSlot: DkColumnMeshSlot, fromPanel: DkColumnStructure<T, P>, destinationPanel: DkColumnStructure<T, P>): DkColumnDef[];
    abstract moveColumnSlotToGutterSlotInDifferentPanel(sourcePanel: DkColumnStructure<T, P>, sourceSlot: DkColumnMeshSlot, destinationPanel: DkColumnStructure<T, P>, destinationSlot: DkMeshSlot): void;
    abstract swapColumnSlotsInDifferentPanel(sourcePanel: DkColumnStructure<T, P>, sourceSlot: DkColumnMeshSlot, destinationPanel: DkColumnStructure<T, P>, destinationSlot: DkColumnMeshSlot): void;
    abstract joinColumnGroupSlots(sourcePanel: DkColumnStructure<T, P>, sourceSlot: DkColumnMeshSlot, destinationPanel: DkColumnStructure<T, P>, destinationSlot: DkColumnMeshSlot): void;
    protected abstract setChangeDataColumnSlotsSubscription(): void;
    protected abstract setChangeColumnSlotsSubscription(): void;
    protected abstract setChangeListHeightSubscription(): void;
    protected abstract setChangeShareableDropElementsSubscription(): void;
}
